
# -----------------------------------------------------------------------
# TCUSTOMER
# -----------------------------------------------------------------------
drop table if exists TCUSTOMER;

CREATE TABLE TCUSTOMER
(
    OBJECTID INTEGER NOT NULL,
    CUSTOMERID VARCHAR(30) NOT NULL,
    CNAME1 VARCHAR(60) NOT NULL,
    CNAME2 VARCHAR(60),
    DELETED INTEGER,
    PRIMARY KEY(OBJECTID),
    INDEX CUSTOMERID (CUSTOMERID));


# -----------------------------------------------------------------------
# TCONTACTPARTNER
# -----------------------------------------------------------------------
drop table if exists TCONTACTPARTNER;

CREATE TABLE TCONTACTPARTNER
(
    OBJECTID INTEGER NOT NULL,
    CUSTOMER INTEGER NOT NULL,
    CRMOBJECTID INTEGER NOT NULL,
    DEPARTMENT VARCHAR(40),
    FIRSTNAME VARCHAR(60),
    LASTNAME VARCHAR(60),
    SALUTATION VARCHAR(20),
    TITLE VARCHAR(20),
    ADDRESS INTEGER,
    JOBFUNCTION VARCHAR(60),
    PHONE VARCHAR(30),
    MOBILE VARCHAR(30),
    FAX VARCHAR(30),
    PRIVATEPHONE VARCHAR(30),
    EMAIL VARCHAR(60),
    DELETED INTEGER,
    LASTCHANGED TIMESTAMP,
    PRIMARY KEY(OBJECTID));


# -----------------------------------------------------------------------
# TADDRESS
# -----------------------------------------------------------------------
drop table if exists TADDRESS;

CREATE TABLE TADDRESS
(
    OBJECTID INTEGER NOT NULL,
    ADDRESSTYPE INTEGER,
    CUSTOMER INTEGER,
    STREET VARCHAR(60),
    DISTRICT VARCHAR(60),
    CITY VARCHAR(60),
    COUNTY VARCHAR(60),
    STATE VARCHAR(60),
    POSTALCODE VARCHAR(20),
    COUNTRY INTEGER,
    COMPANYID VARCHAR(30),
    SUPPLIERID VARCHAR(30),
    SALESORGID VARCHAR(30),
    SUPPLIERCOUNTRY INTEGER,
    PRIMARY KEY(OBJECTID));


# -----------------------------------------------------------------------
# TCOUNTRY
# -----------------------------------------------------------------------
drop table if exists TCOUNTRY;

CREATE TABLE TCOUNTRY
(
    OBJECTID INTEGER NOT NULL,
    COUNTRY VARCHAR(50),
    ISOCODE INTEGER,
    PRIMARY KEY(OBJECTID),
    INDEX ISOCODE (ISOCODE));


# -----------------------------------------------------------------------
# TCRMFIELDVALUE
# -----------------------------------------------------------------------
drop table if exists TCRMFIELDVALUE;

CREATE TABLE TCRMFIELDVALUE
(
    OBJECTID INTEGER NOT NULL,
    CRMFIELD INTEGER NOT NULL,
    DELETED INTEGER,
    CUSTOMER INTEGER,
    CONTACTPARTNER INTEGER,
    NUMERICVALUE INTEGER,
    TIMESTAMPVALUE TIMESTAMP,
    LONGTEXTVALUE MEDIUMTEXT,
    PERSON INTEGER,
    OPTIONID INTEGER,
    CHARVALUE VARCHAR(255),
    DISPLAYVALUE VARCHAR(255),
    PRIMARY KEY(OBJECTID));


# -----------------------------------------------------------------------
# TCRMFIELD
# -----------------------------------------------------------------------
drop table if exists TCRMFIELD;

CREATE TABLE TCRMFIELD
(
    OBJECTID INTEGER NOT NULL,
    ATTRIBUTENAME VARCHAR(255) NOT NULL,
    ATTRIBUTETYPE INTEGER NOT NULL,
    DELETED INTEGER,
    DESCRIPTION VARCHAR(64),
    PERMISSION VARCHAR(255),
    REQUIREDOPTION INTEGER,
    PRIMARY KEY(OBJECTID));


# -----------------------------------------------------------------------
# TCRMFIELDOPTION
# -----------------------------------------------------------------------
drop table if exists TCRMFIELDOPTION;

CREATE TABLE TCRMFIELDOPTION
(
    OBJECTID INTEGER NOT NULL,
    CRMFIELD INTEGER NOT NULL,
    PARENTOPTION INTEGER,
    OPTIONNAME VARCHAR(255) NOT NULL,
    DELETED INTEGER,
    SORTORDER INTEGER,
    PRIMARY KEY(OBJECTID));


# -----------------------------------------------------------------------
# TCRMSOURCE
# -----------------------------------------------------------------------
drop table if exists TCRMSOURCE;

CREATE TABLE TCRMSOURCE
(
    CRMOBJECTID INTEGER NOT NULL,
    CUSTOMERID VARCHAR(30) NOT NULL,
    CNAME1 VARCHAR(60),
    CNAME2 VARCHAR(60),
    STREET VARCHAR(60),
    DISTRICT VARCHAR(60),
    CITY VARCHAR(60),
    COUNTY VARCHAR(60),
    STATE VARCHAR(60),
    POSTALCODE VARCHAR(20),
    COUNTRY INTEGER,
    DEPARTMENT VARCHAR(40),
    FIRSTNAME VARCHAR(60),
    LASTNAME VARCHAR(60),
    SALUTATION VARCHAR(20),
    TITLE VARCHAR(20),
    JOBFUNCTION VARCHAR(60),
    PHONE VARCHAR(30),
    MOBILE VARCHAR(30),
    FAX VARCHAR(30),
    PRIVATEPHONE VARCHAR(30),
    EMAIL VARCHAR(60),
    ACTION INTEGER,
    COMPANY_ID VARCHAR(30),
    SUPPLIER_ID VARCHAR(30),
    SALES_ORGANIZATION_ID VARCHAR(30),
    SUPPLIER_COUNTRY INTEGER,
    LASTCHANGED TIMESTAMP,
    PRIMARY KEY(CRMOBJECTID));

ALTER TABLE TCONTACTPARTNER
    ADD CONSTRAINT TCONTACTPARTNER_FK_1
    FOREIGN KEY (CUSTOMER)
    REFERENCES TCUSTOMER (OBJECTID)
;

ALTER TABLE TCONTACTPARTNER
    ADD CONSTRAINT TCONTACTPARTNER_FK_2
    FOREIGN KEY (ADDRESS)
    REFERENCES TADDRESS (OBJECTID)
;

ALTER TABLE TADDRESS
    ADD CONSTRAINT TADDRESS_FK_1
    FOREIGN KEY (COUNTRY)
    REFERENCES TCOUNTRY (OBJECTID)
;

ALTER TABLE TADDRESS
    ADD CONSTRAINT TADDRESS_FK_2
    FOREIGN KEY (SUPPLIERCOUNTRY)
    REFERENCES TCOUNTRY (OBJECTID)
;

ALTER TABLE TADDRESS
    ADD CONSTRAINT TADDRESS_FK_3
    FOREIGN KEY (CUSTOMER)
    REFERENCES TCUSTOMER (OBJECTID)
;

ALTER TABLE TCRMFIELDVALUE
    ADD CONSTRAINT TCRMFIELDVALUE_FK_1
    FOREIGN KEY (CUSTOMER)
    REFERENCES TCUSTOMER (OBJECTID)
;

ALTER TABLE TCRMFIELDVALUE
    ADD CONSTRAINT TCRMFIELDVALUE_FK_2
    FOREIGN KEY (CONTACTPARTNER)
    REFERENCES TCONTACTPARTNER (OBJECTID)
;

ALTER TABLE TCRMFIELDVALUE
    ADD CONSTRAINT TCRMFIELDVALUE_FK_3
    FOREIGN KEY (PERSON)
    REFERENCES TCONTACTPARTNER (OBJECTID)
;

ALTER TABLE TCRMFIELDVALUE
    ADD CONSTRAINT TCRMFIELDVALUE_FK_4
    FOREIGN KEY (CRMFIELD)
    REFERENCES TCRMFIELD (OBJECTID)
;

ALTER TABLE TCRMFIELDVALUE
    ADD CONSTRAINT TCRMFIELDVALUE_FK_5
    FOREIGN KEY (OPTIONID)
    REFERENCES TCRMFIELDOPTION (OBJECTID)
;

ALTER TABLE TCRMFIELD
    ADD CONSTRAINT TCRMFIELD_FK_1
    FOREIGN KEY (REQUIREDOPTION)
    REFERENCES TCRMFIELDOPTION (OBJECTID)
;

ALTER TABLE TCRMFIELDOPTION
    ADD CONSTRAINT TCRMFIELDOPTION_FK_1
    FOREIGN KEY (CRMFIELD)
    REFERENCES TCRMFIELD (OBJECTID)
;

