
-----------------------------------------------------------------------------
-- TCUSTOMER
-----------------------------------------------------------------------------
DROP TABLE TCUSTOMER CASCADE CONSTRAINTS;

CREATE TABLE TCUSTOMER
(
    OBJECTID NUMBER(10,0) NOT NULL,
    CUSTOMERID VARCHAR2(30) NOT NULL,
    CNAME1 VARCHAR2(60) NOT NULL,
    CNAME2 VARCHAR2(60),
    DELETED NUMBER(10,0)
);

ALTER TABLE TCUSTOMER
    ADD CONSTRAINT TCUSTOMER_PK
PRIMARY KEY (OBJECTID);

CREATE INDEX CUSTOMERID ON TCUSTOMER (CUSTOMERID);


COMMENT ON TABLE TCUSTOMER IS 'The customer company.';



-----------------------------------------------------------------------------
-- TCONTACTPARTNER
-----------------------------------------------------------------------------
DROP TABLE TCONTACTPARTNER CASCADE CONSTRAINTS;

CREATE TABLE TCONTACTPARTNER
(
    OBJECTID NUMBER(10,0) NOT NULL,
    CUSTOMER NUMBER(10,0) NOT NULL,
    CRMOBJECTID NUMBER(10,0) NOT NULL,
    DEPARTMENT VARCHAR2(40),
    FIRSTNAME VARCHAR2(60),
    LASTNAME VARCHAR2(60),
    SALUTATION VARCHAR2(20),
    TITLE VARCHAR2(20),
    ADDRESS NUMBER(10,0),
    JOBFUNCTION VARCHAR2(60),
    PHONE VARCHAR2(30),
    MOBILE VARCHAR2(30),
    FAX VARCHAR2(30),
    PRIVATEPHONE VARCHAR2(30),
    EMAIL VARCHAR2(60),
    DELETED NUMBER(10,0),
    LASTCHANGED TIMESTAMP
);

ALTER TABLE TCONTACTPARTNER
    ADD CONSTRAINT TCONTACTPARTNER_PK
PRIMARY KEY (OBJECTID);



COMMENT ON TABLE TCONTACTPARTNER IS 'The contact person within the customers company.';



-----------------------------------------------------------------------------
-- TADDRESS
-----------------------------------------------------------------------------
DROP TABLE TADDRESS CASCADE CONSTRAINTS;

CREATE TABLE TADDRESS
(
    OBJECTID NUMBER(10,0) NOT NULL,
    ADDRESSTYPE NUMBER(10,0),
    CUSTOMER NUMBER(10,0),
    STREET VARCHAR2(60),
    DISTRICT VARCHAR2(60),
    CITY VARCHAR2(60),
    COUNTY VARCHAR2(60),
    STATE VARCHAR2(60),
    POSTALCODE VARCHAR2(20),
    COUNTRY NUMBER(10,0),
    COMPANYID VARCHAR2(30),
    SUPPLIERID VARCHAR2(30),
    SALESORGID VARCHAR2(30),
    SUPPLIERCOUNTRY NUMBER(10,0)
);

ALTER TABLE TADDRESS
    ADD CONSTRAINT TADDRESS_PK
PRIMARY KEY (OBJECTID);



COMMENT ON TABLE TADDRESS IS 'Address of customer company or contact.';

COMMENT ON COLUMN TADDRESS.ADDRESSTYPE IS '0 or null: company address, 1: contact person address';
COMMENT ON COLUMN TADDRESS.COMPANYID IS 'Buchungskreis aus SAP';
COMMENT ON COLUMN TADDRESS.SUPPLIERID IS 'alte Mimik zur Differenzierung der Kundennummern/-daten, insbesondere bei NON-SAP-GU';
COMMENT ON COLUMN TADDRESS.SUPPLIERCOUNTRY IS 'Land, in welchem das liefernde GU sitzt (nicht das Land des Kunden -> das steht in COUNTRY';


-----------------------------------------------------------------------------
-- TCOUNTRY
-----------------------------------------------------------------------------
DROP TABLE TCOUNTRY CASCADE CONSTRAINTS;

CREATE TABLE TCOUNTRY
(
    OBJECTID NUMBER(10,0) NOT NULL,
    COUNTRY VARCHAR2(50),
    ISOCODE NUMBER(10,0)
);

ALTER TABLE TCOUNTRY
    ADD CONSTRAINT TCOUNTRY_PK
PRIMARY KEY (OBJECTID);

CREATE INDEX ISOCODE ON TCOUNTRY (ISOCODE);


COMMENT ON TABLE TCOUNTRY IS 'Address of customer company or contact.';



-----------------------------------------------------------------------------
-- TCRMFIELDVALUE
-----------------------------------------------------------------------------
DROP TABLE TCRMFIELDVALUE CASCADE CONSTRAINTS;

CREATE TABLE TCRMFIELDVALUE
(
    OBJECTID NUMBER(10,0) NOT NULL,
    CRMFIELD NUMBER(10,0) NOT NULL,
    DELETED NUMBER(10,0),
    CUSTOMER NUMBER(10,0),
    CONTACTPARTNER NUMBER(10,0),
    NUMERICVALUE NUMBER(10,0),
    TIMESTAMPVALUE TIMESTAMP,
    LONGTEXTVALUE VARCHAR2(4000),
    PERSON NUMBER(10,0),
    OPTIONID NUMBER(10,0),
    CHARVALUE VARCHAR2(255),
    DISPLAYVALUE VARCHAR2(255)
);

ALTER TABLE TCRMFIELDVALUE
    ADD CONSTRAINT TCRMFIELDVALUE_PK
PRIMARY KEY (OBJECTID);



COMMENT ON TABLE TCRMFIELDVALUE IS 'Generic field values for crm entities.';



-----------------------------------------------------------------------------
-- TCRMFIELD
-----------------------------------------------------------------------------
DROP TABLE TCRMFIELD CASCADE CONSTRAINTS;

CREATE TABLE TCRMFIELD
(
    OBJECTID NUMBER(10,0) NOT NULL,
    ATTRIBUTENAME VARCHAR2(255) NOT NULL,
    ATTRIBUTETYPE NUMBER(10,0) NOT NULL,
    DELETED NUMBER(10,0),
    DESCRIPTION VARCHAR2(64),
    PERMISSION VARCHAR2(255),
    REQUIREDOPTION NUMBER(10,0)
);

ALTER TABLE TCRMFIELD
    ADD CONSTRAINT TCRMFIELD_PK
PRIMARY KEY (OBJECTID);






-----------------------------------------------------------------------------
-- TCRMFIELDOPTION
-----------------------------------------------------------------------------
DROP TABLE TCRMFIELDOPTION CASCADE CONSTRAINTS;

CREATE TABLE TCRMFIELDOPTION
(
    OBJECTID NUMBER(10,0) NOT NULL,
    CRMFIELD NUMBER(10,0) NOT NULL,
    PARENTOPTION NUMBER(10,0),
    OPTIONNAME VARCHAR2(255) NOT NULL,
    DELETED NUMBER(10,0),
    SORTORDER NUMBER(10,0)
);

ALTER TABLE TCRMFIELDOPTION
    ADD CONSTRAINT TCRMFIELDOPTION_PK
PRIMARY KEY (OBJECTID);






-----------------------------------------------------------------------------
-- TCRMSOURCE
-----------------------------------------------------------------------------
DROP TABLE TCRMSOURCE CASCADE CONSTRAINTS;

CREATE TABLE TCRMSOURCE
(
    CRMOBJECTID NUMBER(10,0) NOT NULL,
    CUSTOMERID VARCHAR2(30) NOT NULL,
    CNAME1 VARCHAR2(60),
    CNAME2 VARCHAR2(60),
    STREET VARCHAR2(60),
    DISTRICT VARCHAR2(60),
    CITY VARCHAR2(60),
    COUNTY VARCHAR2(60),
    STATE VARCHAR2(60),
    POSTALCODE VARCHAR2(20),
    COUNTRY NUMBER(10,0),
    DEPARTMENT VARCHAR2(40),
    FIRSTNAME VARCHAR2(60),
    LASTNAME VARCHAR2(60),
    SALUTATION VARCHAR2(20),
    TITLE VARCHAR2(20),
    JOBFUNCTION VARCHAR2(60),
    PHONE VARCHAR2(30),
    MOBILE VARCHAR2(30),
    FAX VARCHAR2(30),
    PRIVATEPHONE VARCHAR2(30),
    EMAIL VARCHAR2(60),
    ACTION NUMBER(10,0),
    COMPANY_ID VARCHAR2(30),
    SUPPLIER_ID VARCHAR2(30),
    SALES_ORGANIZATION_ID VARCHAR2(30),
    SUPPLIER_COUNTRY NUMBER(10,0),
    LASTCHANGED TIMESTAMP
);

ALTER TABLE TCRMSOURCE
    ADD CONSTRAINT TCRMSOURCE_PK
PRIMARY KEY (CRMOBJECTID);



COMMENT ON TABLE TCRMSOURCE IS 'The original source from which we synchronize our own entities.';

COMMENT ON COLUMN TCRMSOURCE.ACTION IS '1=add, 2=update, 3=delete';
COMMENT ON COLUMN TCRMSOURCE.COMPANY_ID IS 'Buchungskreis aus SAP';
COMMENT ON COLUMN TCRMSOURCE.SUPPLIER_ID IS 'alte Mimik zur Differenzierung der Kundennummern/-daten, insbesondere bei NON-SAP-GU';
COMMENT ON COLUMN TCRMSOURCE.SUPPLIER_COUNTRY IS 'Land, in welchem das liefernde GU sitzt (nicht das Land des Kunden -> das steht in COUNTRY';



ALTER TABLE TCONTACTPARTNER
    ADD CONSTRAINT TCONTACTPARTNER_FK_1 FOREIGN KEY (CUSTOMER)
    REFERENCES TCUSTOMER (OBJECTID)
;

ALTER TABLE TCONTACTPARTNER
    ADD CONSTRAINT TCONTACTPARTNER_FK_2 FOREIGN KEY (ADDRESS)
    REFERENCES TADDRESS (OBJECTID)
;



ALTER TABLE TADDRESS
    ADD CONSTRAINT TADDRESS_FK_1 FOREIGN KEY (COUNTRY)
    REFERENCES TCOUNTRY (OBJECTID)
;

ALTER TABLE TADDRESS
    ADD CONSTRAINT TADDRESS_FK_2 FOREIGN KEY (SUPPLIERCOUNTRY)
    REFERENCES TCOUNTRY (OBJECTID)
;

ALTER TABLE TADDRESS
    ADD CONSTRAINT TADDRESS_FK_3 FOREIGN KEY (CUSTOMER)
    REFERENCES TCUSTOMER (OBJECTID)
;





ALTER TABLE TCRMFIELDVALUE
    ADD CONSTRAINT TCRMFIELDVALUE_FK_1 FOREIGN KEY (CUSTOMER)
    REFERENCES TCUSTOMER (OBJECTID)
;

ALTER TABLE TCRMFIELDVALUE
    ADD CONSTRAINT TCRMFIELDVALUE_FK_2 FOREIGN KEY (CONTACTPARTNER)
    REFERENCES TCONTACTPARTNER (OBJECTID)
;

ALTER TABLE TCRMFIELDVALUE
    ADD CONSTRAINT TCRMFIELDVALUE_FK_3 FOREIGN KEY (PERSON)
    REFERENCES TCONTACTPARTNER (OBJECTID)
;

ALTER TABLE TCRMFIELDVALUE
    ADD CONSTRAINT TCRMFIELDVALUE_FK_4 FOREIGN KEY (CRMFIELD)
    REFERENCES TCRMFIELD (OBJECTID)
;

ALTER TABLE TCRMFIELDVALUE
    ADD CONSTRAINT TCRMFIELDVALUE_FK_5 FOREIGN KEY (OPTIONID)
    REFERENCES TCRMFIELDOPTION (OBJECTID)
;



ALTER TABLE TCRMFIELD
    ADD CONSTRAINT TCRMFIELD_FK_1 FOREIGN KEY (REQUIREDOPTION)
    REFERENCES TCRMFIELDOPTION (OBJECTID)
;



ALTER TABLE TCRMFIELDOPTION
    ADD CONSTRAINT TCRMFIELDOPTION_FK_1 FOREIGN KEY (CRMFIELD)
    REFERENCES TCRMFIELD (OBJECTID)
;





